@@ -496,6 +496,7 @@ class Ultimate_Classification():
         print('total time taken is', ((end-start)/60),'minutes')
         print('-'*50)
         #funtion to return all the values 
+    
     def f1_score(self):
         print('overall f1_score train data: ',self.f1_score_train)
         print('overall f1_score test data: ',self.f1_score_test)
@@ -536,6 +537,18 @@ class Ultimate_Classification():
         print("Accuracy: %0.3f (+/- %0.3f)" % (self.scores_train.mean(), self.scores_train.std() * 2))
         print("Accuracy: %0.2f (+/- %0.2f)" % (self.scores_test.mean(), self.scores_test.std() * 2))
 
+    def runAll(self):
+        self.start()
+        self.accuracy_meanFill()
+        self.accuracy_zeroFill()
+        self.accuracy_medianFill()
+        self.f1_score()
+        self.confusion_matrix()
+        self.classification_report()
+        #self.roc_auc_score
+        self.columns()
+        #self.best_model()
+        self.cross_validation()
 
 class Ultimate_Regression():
     def start(self): 
@@ -866,35 +879,37 @@ class Ultimate_Regression():
 
         self.bestModel=''
         self.bestModelName=''
-        if(r2_t_rfr>r2_t_dt)&(r2_t_rfr>r2_t_en)&(r2_t_rfr>r2_t_lr)&(r2_t_rfr>r2_t_gbr)&(r2_t_rfr>r2_t_r):
+        l={'rfr':r2_t_rfr,'dt':r2_t_dt,'en':r2_t_en,'lr':r2_t_lr,'gbr':r2_t_gbr,'r':r2_t_r}
+        max_model=[k for k,v in l.items() if v==max(l.values())]
+        if max_model[0]=='rfr':
             self.bestModel=rfr
             self.bestModelName='random_forest_regressor'
             y_pred_train=y_pred_train_rfr
             y_pred=y_pred_rfr
             r2_best_train=r2_tr_rfr
             r2_best_test=r2_t_rfr
-        elif(r2_t_en>r2_t_gbr)&(r2_t_en>r2_t_lr)&(r2_t_en>r2_t_dt)&(r2_t_en>r2_t_r):
+        elif max_model[0]=='en':
             self.bestModel=en
             self.bestModelName='elasticNet'
             y_pred_train=y_pred_train_en
             y_pred=y_pred_en
             r2_best_train=r2_tr_en
             r2_best_test=r2_t_en
-        elif(r2_t_gbr>r2_t_dt)&(r2_t_gbr>r2_t_lr)&(r2_t_gbr>r2_t_r):
+        elif max_model[0]=='gbr':
             self.bestModel=gbr
             self.bestModelName='gradient_boosting_regression'
             y_pred_train=y_pred_train_gbr
             y_pred=y_pred_gbr
             r2_best_train=r2_tr_gbr
             r2_best_test=r2_t_gbr
-        elif(r2_t_dt>r2_t_lr)&(r2_t_dt>r2_t_r):
+        elif max_model[0]=='dt':
             self.bestModel=dt
             self.bestModelName='decision_tree'
             y_pred_train=y_pred_train_dt
             y_pred=y_pred_dt
             r2_best_train=r2_tr_dt
             r2_best_test=r2_t_dt
-        elif(r2_t_lr>r2_t_r)&(r2_t_lr<100):
+        elif max_model[0]=='lr':
             self.bestModel=lr
             self.bestModelName='linear_regression'
             y_pred_train=y_pred_train_lr
@@ -954,7 +969,7 @@ class Ultimate_Regression():
         print('overall r2 train data using voting regressor: ',r2_tr_vr)
         print('overall r2 test data using voting regressor: ',r2_t_vr)
 
-        if (r2_t_vr>99.5):
+        if (r2_t_vr>99.9995):
             self.bestModel=vr
             self.bestModelName='Voting_regressor'
             y_pred_train=y_pred_train_vr
@@ -1002,21 +1017,54 @@ class Ultimate_Regression():
         print('continuous columns retained after vif are:',self.vif_columns)
         print('Final columns that are retained are',self.cols)
         print('Final columns after doing one hot encoding are: ',self.col_dummies)
-    
-if __name__=='__main__':
-    reg_flag=input('input y or n for reg')
-    if reg_flag.lower()=='y':
-        ul=Ultimate_Regression()
-    else:
-        ul=Ultimate_Classification()
-    ul.start()
-    ul.accuracy_meanFill()
-    ul.accuracy_zeroFill()
-    ul.accuracy_medianFill()
-    ul.f1_score()
-    ul.confusion_matrix()
-    ul.classification_report()
-    #ul.roc_auc_score
-    ul.columns()
-    ul.best_model()
-    ul.cross_validation()
+        try:
+            print(f'Feature Importance:',self.bestModel.feature_importances_)
+        except Exception as e:
+            pass
+
+class createModel():
+    def __init__(self):
+        self.reg_flag=input('input y or n for reg').lower()
+        if self.reg_flag.lower()=='y':
+            self.ul=Ultimate_Regression()
+        else:
+            self.ul=Ultimate_Classification()
+        self.ul.start()
+    def r2_meanFill(self):
+        if self.reg_flag=='y':	
+            self.ul.r2_meanFill()
+    def r2_zeroFill(self):
+        if self.reg_flag=='y':	
+            self.ul.r2_zeroFill()
+    def r2_medianFill(self):
+        if self.reg_flag=='y':	
+            self.ul.r2_medianFill()
+    def mae(self):
+        if self.reg_flag=='y':	
+            self.ul.mae()
+    def mse(self):
+        if self.reg_flag=='y':	
+            self.ul.mse()
+    def columns(self):
+        self.ul.columns()
+    def accuracy_meanFill(self):
+        if self.reg_flag!='y':		
+            self.ul.accuracy_meanFill()
+    def accuracy_zeroFill(self):
+        if self.reg_flag!='y':		
+            self.ul.accuracy_zeroFill()
+    def accuracy_medianFill(self):
+        if self.reg_flag!='y':		
+            self.ul.accuracy_medianFill()
+    def f1_score(self):
+        if self.reg_flag!='y':		
+            self.ul.f1_score()
+    def confusion_matrix(self):
+        if self.reg_flag!='y':		
+            self.ul.confusion_matrix()
+    def classification_report(self):
+        if self.reg_flag!='y':		
+            self.ul.classification_report()
+    def cross_validation(self):
+        if self.reg_flag!='y':		
+            self.ul.cross_validation()
